/*****************************************************************************
**
** cdt.h: a C interface to the CDT routines
**
** Copyright (C) 1995 by Dani Lischinski 
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**
******************************************************************************/

#ifndef CDT_H
#define CDT_H

#ifdef __cplusplus
extern "C" {
#endif

/* 
 * create_mesh initializes a mesh given an array bdry_vertices,
 * assumed to contain 2*num_bdry_vertices coordinates of the
 * boundary vertices of a convex polygon.
 * It return a pointer to the mesh data structure, which should
 * be used as the first argument for the other routines.
 */
void *create_mesh( int num_bdry_vertices, double *bdry_vertices );

void insert_vertex( void *mesh, double x, double y );

void insert_edge( void *mesh, double x1, double y1, double x2, double y2 );

void apply_vertices(
	void *mesh, void *apply_arg,
	void (*func)( void *apply_arg, void *vertex ));
					 
void apply_edges(
	void *mesh, void *apply_arg,
	void (*func)( void *apply_arg, void *edge, int constrained ));
					 
void draw_mesh( void *mesh, int output_postscript );

void destroy_mesh( void *mesh );

#ifdef __cplusplus
}
#endif

#endif /* CDT_H */
